==> aws-java-sdk-kinesis-1.10.25-sources.jar: com/amazonaws/services/kinesisfirehose/model/transform/DeliveryStreamDescriptionJsonMarshaller.java <==
/*
 * Copyright 2010-2015 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.kinesisfirehose.model.transform;

import static com.amazonaws.util.StringUtils.UTF8;
import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.OutputStreamWriter;
import java.io.StringWriter;
import java.io.Writer;
import java.util.Map;
import java.util.List;

import com.amazonaws.AmazonClientException;
import com.amazonaws.services.kinesisfirehose.model.*;
import com.amazonaws.transform.Marshaller;
import com.amazonaws.util.BinaryUtils;
import com.amazonaws.util.StringUtils;
import com.amazonaws.util.StringInputStream;
import com.amazonaws.util.json.*;

/**
 * DeliveryStreamDescriptionMarshaller
 */
public class DeliveryStreamDescriptionJsonMarshaller {

    /**
     * Marshall the given parameter object, and output to a JSONWriter
     */
    public void marshall(DeliveryStreamDescription deliveryStreamDescription,
            JSONWriter jsonWriter) {
        if (deliveryStreamDescription == null) {
            throw new AmazonClientException(
                    "Invalid argument passed to marshall(...)");
        }

        try {
            jsonWriter.object();

            if (deliveryStreamDescription.getDeliveryStreamName() != null) {
                jsonWriter.key("DeliveryStreamName").value(
                        deliveryStreamDescription.getDeliveryStreamName());
            }

            if (deliveryStreamDescription.getDeliveryStreamARN() != null) {
                jsonWriter.key("DeliveryStreamARN").value(
                        deliveryStreamDescription.getDeliveryStreamARN());
            }

            if (deliveryStreamDescription.getDeliveryStreamStatus() != null) {
                jsonWriter.key("DeliveryStreamStatus").value(
                        deliveryStreamDescription.getDeliveryStreamStatus());
            }

            if (deliveryStreamDescription.getVersionId() != null) {
                jsonWriter.key("VersionId").value(
                        deliveryStreamDescription.getVersionId());
            }

            if (deliveryStreamDescription.getCreateTimestamp() != null) {
                jsonWriter.key("CreateTimestamp").value(
                        deliveryStreamDescription.getCreateTimestamp());
            }

            if (deliveryStreamDescription.getLastUpdateTimestamp() != null) {
                jsonWriter.key("LastUpdateTimestamp").value(
                        deliveryStreamDescription.getLastUpdateTimestamp());
            }

            java.util.List<DestinationDescription> destinationsList = deliveryStreamDescription
                    .getDestinations();
            if (destinationsList != null) {
                jsonWriter.key("Destinations");
                jsonWriter.array();
                for (DestinationDescription destinationsListValue : destinationsList) {
                    if (destinationsListValue != null) {

                        DestinationDescriptionJsonMarshaller.getInstance()
                                .marshall(destinationsListValue, jsonWriter);
                    }
                }
                jsonWriter.endArray();
            }

            if (deliveryStreamDescription.getHasMoreDestinations() != null) {
                jsonWriter.key("HasMoreDestinations").value(
                        deliveryStreamDescription.getHasMoreDestinations());
            }

            jsonWriter.endObject();
        } catch (Throwable t) {
            throw new AmazonClientException(
                    "Unable to marshall request to JSON: " + t.getMessage(), t);
        }
    }

    private static DeliveryStreamDescriptionJsonMarshaller instance;

    public static DeliveryStreamDescriptionJsonMarshaller getInstance() {
        if (instance == null)
            instance = new DeliveryStreamDescriptionJsonMarshaller();
        return instance;
    }

}

==> aws-java-sdk-kinesis-1.11.29-sources.jar: com/amazonaws/services/kinesisfirehose/model/transform/DeliveryStreamDescriptionJsonMarshaller.java <==
/*
 * Copyright 2011-2016 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"). You may not
 * use this file except in compliance with the License. A copy of the License is
 * located at
 * 
 * http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */
package com.amazonaws.services.kinesisfirehose.model.transform;

import java.util.Map;
import java.util.List;

import com.amazonaws.AmazonClientException;
import com.amazonaws.services.kinesisfirehose.model.*;
import com.amazonaws.transform.Marshaller;
import com.amazonaws.util.BinaryUtils;
import com.amazonaws.util.StringUtils;
import com.amazonaws.util.IdempotentUtils;
import com.amazonaws.util.StringInputStream;
import com.amazonaws.protocol.json.*;

/**
 * DeliveryStreamDescriptionMarshaller
 */
public class DeliveryStreamDescriptionJsonMarshaller {

    /**
     * Marshall the given parameter object, and output to a SdkJsonGenerator
     */
    public void marshall(DeliveryStreamDescription deliveryStreamDescription,
            StructuredJsonGenerator jsonGenerator) {

        if (deliveryStreamDescription == null) {
            throw new AmazonClientException(
                    "Invalid argument passed to marshall(...)");
        }

        try {
            jsonGenerator.writeStartObject();

            if (deliveryStreamDescription.getDeliveryStreamName() != null) {
                jsonGenerator.writeFieldName("DeliveryStreamName").writeValue(
                        deliveryStreamDescription.getDeliveryStreamName());
            }
            if (deliveryStreamDescription.getDeliveryStreamARN() != null) {
                jsonGenerator.writeFieldName("DeliveryStreamARN").writeValue(
                        deliveryStreamDescription.getDeliveryStreamARN());
            }
            if (deliveryStreamDescription.getDeliveryStreamStatus() != null) {
                jsonGenerator.writeFieldName("DeliveryStreamStatus")
                        .writeValue(
                                deliveryStreamDescription
                                        .getDeliveryStreamStatus());
            }
            if (deliveryStreamDescription.getVersionId() != null) {
                jsonGenerator.writeFieldName("VersionId").writeValue(
                        deliveryStreamDescription.getVersionId());
            }
            if (deliveryStreamDescription.getCreateTimestamp() != null) {
                jsonGenerator.writeFieldName("CreateTimestamp").writeValue(
                        deliveryStreamDescription.getCreateTimestamp());
            }
            if (deliveryStreamDescription.getLastUpdateTimestamp() != null) {
                jsonGenerator.writeFieldName("LastUpdateTimestamp").writeValue(
                        deliveryStreamDescription.getLastUpdateTimestamp());
            }

            java.util.List<DestinationDescription> destinationsList = deliveryStreamDescription
                    .getDestinations();
            if (destinationsList != null) {
                jsonGenerator.writeFieldName("Destinations");
                jsonGenerator.writeStartArray();
                for (DestinationDescription destinationsListValue : destinationsList) {
                    if (destinationsListValue != null) {

                        DestinationDescriptionJsonMarshaller.getInstance()
                                .marshall(destinationsListValue, jsonGenerator);
                    }
                }
                jsonGenerator.writeEndArray();
            }
            if (deliveryStreamDescription.getHasMoreDestinations() != null) {
                jsonGenerator.writeFieldName("HasMoreDestinations").writeValue(
                        deliveryStreamDescription.getHasMoreDestinations());
            }

            jsonGenerator.writeEndObject();
        } catch (Throwable t) {
            throw new AmazonClientException(
                    "Unable to marshall request to JSON: " + t.getMessage(), t);
        }
    }

    private static DeliveryStreamDescriptionJsonMarshaller instance;

    public static DeliveryStreamDescriptionJsonMarshaller getInstance() {
        if (instance == null)
            instance = new DeliveryStreamDescriptionJsonMarshaller();
        return instance;
    }

}
